@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2007-2011 Horde LLC (http://www.horde.org/)
+ * Copyright 2007-2012 Horde LLC (http://www.horde.org/)
  *
  * @author   Chuck Hagenbuch <chuck@horde.org>
  * @license  http://www.horde.org/licenses/bsd BSD
@@ -14,6 +14,6 @@
  * @category Horde
  * @package  Http
  */
-class Horde_Http_Exception extends Horde_Exception_LastError
+class Horde_Http_Exception extends Horde_Exception_Wrapped
 {
 }
